--------------------------------------------------------------------------------
-- (c) 2020 Force America, Inc
-- Upgrades a revision 12 database to revision 13
--------------------------------------------------------------------------------

BEGIN TRANSACTION;

ALTER TABLE tow_plow_unload ADD COLUMN direct_unload_time_hms TEXT;

CREATE TABLE tow_plow_simultaneous_granular_direct
(
    snapshot_id                              INTEGER REFERENCES snapshot(snapshot_id),
    granular_material_name                   TEXT,   -- contains same values as granular_material.name
    direct_material_name                     TEXT,   -- contains same values as direct_liquid_material.name
    -- data totals to store
    -- Combined usage
    simultaneous_distance_km                 REAL,
    simultaneous_time_blast_hms              TEXT,
    -- Direct usage
    simultaneous_direct_volume_l             REAL,
    simultaneous_direct_time_closed_hms      TEXT,
    simultaneous_direct_time_open_hms        TEXT,
    simultaneous_direct_time_manual_hms      TEXT,
    -- Granular usage
    simultaneous_granular_weight_kg          REAL,
    simultaneous_granular_time_closed_hms    TEXT,
    simultaneous_granular_time_open_hms      TEXT,
    simultaneous_granular_time_manual_hms    TEXT,
    simultaneous_lane_distance_km            REAL NOT NULL DEFAULT 0,
    -- lane distance is for use with directional spinner
    CONSTRAINT simultaneous_granular_direct_pk
        PRIMARY KEY (snapshot_id, granular_material_name, direct_material_name)
        ON CONFLICT ROLLBACK
);

CREATE TABLE tow_plow_prewetted_simultaneous_granular_direct
(
    snapshot_id                              INTEGER REFERENCES snapshot(snapshot_id),
    granular_material_name                   TEXT,    -- contains same values as granular_material.name
    direct_material_name                     TEXT,    -- contains same values as direct_liquid_material.name
    prewet_material_name                     TEXT,    -- contains same values as prewetted_granular.prewet_material_name
    -- data totals to store
    -- Combined usage
    simultaneous_distance_km                 REAL,
    simultaneous_time_blast_hms              TEXT,
    -- Direct usage
    simultaneous_direct_volume_l             REAL,
    simultaneous_direct_time_closed_hms      TEXT,
    simultaneous_direct_time_open_hms        TEXT,
    simultaneous_direct_time_manual_hms      TEXT,
    -- Prewetted granular usage
    prewetted_material_weight_kg             REAL,
    prewetted_time_open_hms                  TEXT,
    prewetted_time_closed_hms                TEXT,
    prewetted_time_manual_hms                TEXT,
    -- actual prewet material usage
    prewet_material_volume_l                 REAL,
    prewet_material_time_closed_hms          TEXT,
    prewet_material_time_open_hms            TEXT,
    prewet_material_time_manual_hms          TEXT,
    simultaneous_lane_distance_km            REAL NOT NULL DEFAULT 0,
    CONSTRAINT prewetted_simultaneous_granular_direct_pk
        PRIMARY KEY (snapshot_id, prewet_material_name, granular_material_name, direct_material_name)
        ON CONFLICT ROLLBACK
);
-- Delete and remake the table to ensure the it only contains the new value.
DROP TABLE meta;

CREATE TABLE meta
(
    snapshot_schema_version    INTEGER
);

INSERT INTO meta(snapshot_schema_version) VALUES (13);

COMMIT TRANSACTION;
